% Function used by cep.m to compute the true cepstral coeff. and 
% the true spectrum
function [c_p,Phi_p,flag_err] = comp_c_p(A,B,N)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%input:
%   A        = AR part of the model
%   B        = MA part of the model
%   N        = no. of measurements
%output:
%   c_p      = true cepstral coeff.
%   Phi_p    = true spectrum 
%   flag_err = 1 if error; otherwise is 0 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

flag_err = 0;

A = A(:);
B = B(:);

freq = [0:N-1]/N;

i = sqrt(-1);
%AR part
kk = length(A)-1;
Exa = kron(freq',[0:kk]);
Exa = exp(-i*2*pi*Exa);

%MA part
kk = length(B)-1;
Exb = kron(freq',[0:kk]);
Exb = exp(-i*2*pi*Exb);

%true spectrum
Phi_p = (abs(Exb*B).^2)./(abs(Exa*A).^2); 

% true cepstral coeff.
c_p = ifft(log(Phi_p));
if max(abs(imag(c_p)))<10^(-10),
    c_p = real(c_p);
else
    fprintf('ERROR: in the evaluation of c_p.\n');
    flag_err = 1;
end

