% The function computes \mu_{KSF} by using the KSFM criterion
function mu_KSF = comp_mu_KSF_mod(c_e,N,M,Lk,vec_mu,ex,flag_plot)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%input:
%   c_e       = estimated cepstral coeff.
%   N         = no. of measurements
%   M         = M = N/2+1
%   Lk        = code length for the structure
%   vec_mu    = grid for \mu
%   ex        = no. of the current experiment (used only for plots)
%   flag_plot = if flag_plot=2, then the following plots are generated:
%               L versus \mu_{KSF} and k versus \mu_{KSF}
%output:
%   mu_KSF    = KSF threshold
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

s = pi/sqrt(N)*[1/sqrt(3); 1/sqrt(6)*ones(N/2-1,1); 1/sqrt(3)];
x = c_e(1:M)./s;
[ax_ord,ind] = sort(abs(x),'descend');
x_ord = x(ind);

%\ell <-> h_slen
h_slen = 0;
mu_KSF = 1 + h_slen;
%For h_slen = 0, KSFM function is Inf !!!!
Lbest = Inf;

if flag_plot==2,
     L_vec = [];
     mu_KSF_vec = [];
     k_vec = [];
end

vec_mu1 = vec_mu-1;
vec_h = vec_mu1(2:end);
for h_slen=vec_h,
    
    ff = find( ax_ord >= (1+h_slen) );
    k = length(ff);
    if k>0,
        z = x_ord(1:k);
        nt = sum(z.^2);
        logCk = (k/2)*log(nt/k) + k/2 + log(k)/2;
        logQk = -(k/2)*log(2*pi) + k*log(2*h_slen);
        %code length for the signal
        L_signal = Lk(k) + logCk - logQk;
        %code length for noise (distortion)
        L_noise = sum((x_ord(k+1:end)).^2)/2;
        %KSF
        L = L_signal + L_noise;
        if L<Lbest,
            Lbest = L;
            mu_KSF = 1 + h_slen;
        end
        if flag_plot==2,
            L_vec = [L_vec; L];
            mu_KSF_vec = [ mu_KSF_vec; (1 + h_slen)];
            k_vec = [k_vec; k];
        end    
    else
        % h_len is too large; all coeff. are quantized to zero
        break;
    end %k>0
end % for

if flag_plot==2,
    plot_L_k_versus_mu(L_vec,k_vec,mu_KSF_vec,ex,N);
end


