% The function computes \mu_{KSF} by using the KSFM criterion
% The search for the optimum threshold 
% is not performed on the \ell_grid, 
% but for k\in\\{1,\ldots,M-1\}.
function mu_KSF = comp_mu_KSF_mod_2(c_e,N,M,Lk,vec_mu)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%input:
%   c_e       = estimated cepstral coeff.
%   N         = no. of measurements
%   M         = M = N/2+1
%   Lk        = code length for the structure
%   vec_mu    = grid for \mu
%output:
%   mu_KSF    = value of threshold for the modified KSF 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

s = pi/sqrt(N)*[1/sqrt(3); 1/sqrt(6)*ones(N/2-1,1); 1/sqrt(3)];
x = c_e(1:M)./s;
[ax_ord,ind] = sort(abs(x),'descend');
x_ord = x(ind);

Lbest = Inf;
mu_KSF = min(vec_mu);
mu_min = min(vec_mu);
mu_max = max(vec_mu);

ff = find(ax_ord>mu_max);
k1 = max(length(ff),1);
ff = find(ax_ord<=mu_min);
k2 = min(M-length(ff),M-1);

for k=k1:k2,
     h_slen = ax_ord(k)-1;
     z = x_ord(1:k);
     nt = sum(z.^2);
     logCk = (k/2)*log(nt/k) + k/2 + log(k)/2;
     logQk = -(k/2)*log(2*pi) + k*log(2*h_slen);
     %code length for the signal
     L_signal = Lk(k) + logCk - logQk;
     %code length for noise (distortion)
     L_noise = sum((x_ord(k+1:end)).^2)/2;
     %KSF
     L = L_signal + L_noise;
     if L<Lbest,
        Lbest = L;
        mu_KSF = ax_ord(k);
     end
end

%To circumvent some numerical difficulties
mu_KSF = floor(10^10*mu_KSF)/10^10;


