% Auxiliary function: it is used by cep.m to plot the true spectrum 
% and the estimated spectrum
function plot_est_spec(Phi_p,c_til,Phi_p_tmp,N,fig_no,plot_no,ex)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%input
% Phi_p     = true spectrum computed for the Fourier grid with N points  
% c_til     = cepstral coeff. after the small ones have been turned to 0
% Phi_p_tmp = periodogram
% N         = no. of samples 
% fig_no    = current figure
% plot_no   = plot no. within the current figure 
% ex        = which example
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Phi_p_mod = flipud([Phi_p(N/2+1:N); Phi_p(1:N/2)]);
%Spectrum estimated after applying thresholding to the cepstral coeff.
Phi_e_temp = real(exp(fft(c_til)));
alpha = sum(Phi_p_tmp.*Phi_e_temp)/sum(Phi_e_temp.^2);
%Spectrum estimated with eq. (40) from
%P. Stoica & N. Sandgren, IEEE SP Mag., Nov. 2006
Phi_e_tmp = alpha.*Phi_e_temp;
Phi = flipud([Phi_e_tmp(N/2+1:N); Phi_e_tmp(1:N/2)]);
figure(fig_no);
subplot(1,3,plot_no);
xx = (2*pi)*[-(N/2-1):N/2]/N;
plot(xx,10*log10(Phi_p_mod),'r:',xx,10*log10(Phi),'k','LineWidth',2);
set(gca,'PlotBoxAspectRatio',[1 3 1]);
grid;
legend('True \Phi','Est. \Phi');
xlim([-pi pi]);
xlabel('Frequency');
tit = sprintf('Example %i, N=%i',ex,N);
if plot_no==1,
    tit = strcat(tit,' (KSF)');
    title(tit);
elseif plot_no==2,
    tit = strcat(tit,' (BIC)');
    title(tit);
elseif plot_no==3,   
    tit = strcat(tit,' (UMPUT)');
    title(tit);
else
end

