function run_cep(flag_KSF,flag_plot)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%input
% flag_KSF       = 0: KSF criterion;
%                  1: KSFM criterion;
%                  2: KSFM criterion (the search for the optimum threshold
%                     is not performed on the \ell_grid, 
%                     but for k\in\\{1,\ldots,M-1\}.
% flag_plot     
%                = 0 : plots the graphs from the results saved previously
%                = 1 : runs all methods and save the results
%                = 2 : runs all methods, save the results and 
%                      plots L versus \mu_{KSF} & k versus \mu_{KSF}
%                      if flag_KSF<2
%                = 3 : runs all methods, save the results and 
%                      plots the true & the estimated spectra
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

%INIT
%Nr. of runs
Nr = 1000; 
%Sample sizes
vecN = [128 256 512 1024 2048];
%Grid for \mu
vec_mu = [1:0.1:10];
%
% rat_genie1 = zeros(size(vecN));
rat_genie2 = zeros(size(vecN));
rat_KSF = zeros(size(vecN));
rat_BIC = zeros(size(vecN));
rat_UMPUT = zeros(size(vecN));
%
% counter_c_genie1 = zeros(size(vecN));
counter_c_genie2 = zeros(size(vecN));
counter_c_KSF = zeros(size(vecN));
counter_c_BIC = zeros(size(vecN));
counter_c_UMPUT = zeros(size(vecN));

rand('twister',1);
randn('state',1);

for ex=1:5,
    if flag_KSF==0,
        fname = strcat('file_res_ex_',num2str(ex));
    elseif flag_KSF==1,
        fname = strcat('mod_file_res_ex_',num2str(ex));
    elseif flag_KSF==2,
        fname = strcat('mod_2_file_res_ex_',num2str(ex));
    else
        fprintf('ERROR: flag_KSF can take only the following values: 0,1,2.\n');
        return;
    end
    if flag_plot>0,
        fig_no = 2*ex+1;
        for i=1:length(vecN),
            N = vecN(i);
            %run all methods
            [rat counter_c] = cep(Nr,N,vec_mu,ex,flag_KSF,flag_plot);
            
            % rat_genie1(i) = rat(1);
            rat_genie2(i) = rat(2);
            rat_KSF(i) = rat(3);
            rat_BIC(i) = rat(4);
            rat_UMPUT(i) = rat(5); 
            
            % counter_c_genie1(i) = counter_c(1);
            counter_c_genie2(i) = counter_c(2);
            counter_c_KSF(i) = counter_c(3);
            counter_c_BIC(i) = counter_c(4);
            counter_c_UMPUT(i) = counter_c(5); 
              
        end %for i
        %save the results
        eval(['save ' fname ';']);
    else
        fig_no = 2*ex-1;
        %load the existing results
        flag_KSF_old = flag_KSF;
        flag_plot_old = flag_plot;
        eval(['load ' fname]);
        flag_KSF = flag_KSF_old;
        flag_plot = flag_plot_old;
    end
    
    %Plot \rho versus N
    figure(fig_no);
    plot( log2(vecN),rat_genie2,'g', ...
            log2(vecN),rat_KSF,'r', ...
            log2(vecN),rat_BIC,'k', ...
            log2(vecN),rat_UMPUT,'b', ...
            'LineWidth',2);
    if ex==1,
             ylim([0 500]);
    end
    legend('\mu_{genie}','\mu_{KSF}','\mu_{BIC}','\mu_{UMPUT}', ...
         'Location','NorthWest');  
    set(gca,'XTick',log2(vecN));
    set(gca,'XTickLabel',{'128','256','512','1024','2048'})
    xlabel('N');
    ylabel('\rho','Rotation',0);
        
    %Plot the average no. of retained coeff. versus N 
    figure(fig_no+1);
    plot( log2(vecN),counter_c_genie2,'g-+', ...
            log2(vecN),counter_c_KSF,'r->', ...
            log2(vecN),counter_c_BIC,'k-<', ...,
            log2(vecN),counter_c_UMPUT,'b-*', ...
            'MarkerSize',10);
    legend('\mu_{genie}','\mu_{KSF}','\mu_{BIC}','\mu_{UMPUT}', ...
         'Location','SouthEast');  
    set(gca,'XTick',log2(vecN));
    set(gca,'XTickLabel',{'128','256','512','1024','2048'})
    xlabel('N');
    ylabel('Av. no. retained coeff.');
end %ex

 